# CSSType

TypeScript definitions for CSS, generated by [data from MDN](https://github.com/mdn/data). It provides autocompletion and type checking for CSS properties and values.

```ts
import * as CSS from 'csstype';

const style: CSS.Properties = {
  alignSelf: 'stretsh', // Type error on value
  colour: 'white',      // Type error on property
}
```

## Getting started

```bash
$ npm install csstype@latest  # For projects
$ npm install csstype@*       # For libraries
```

## Usage

Lengths defaults to `string`. But it's possible to add `number` as well using generics.

```ts
import * as CSS from 'csstype';

const style: CSS.Properties<string | number> = {
  padding: 10,
  margin: '1rem',
}
```

In some cases, like for CSS-in-JS libraries, an array of values is a way to provide fallback values in CSS. Using `CSS.PropertiesFallback` instead of `CSS.Properties` will add the possibility to use any property value as an array of values. 

```ts
import * as CSS from 'csstype';

const style: CSS.PropertiesFallback = {
  display: [
    '-webkit-flex',
    'flex',
  ],
  color: 'white',
}
```

There's even string literals for pseudo selectors and elements.

```ts
import * as CSS from 'csstype';

const pseudos: { [P in CSS.Pseudos]?: CSS.Properties } = {
  ':hover': {
    display: 'flex',
  },
}
```
